@@ -1,40 +1,29 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2004 Jakub Stachowski <qbast@go2.pl>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2004 Jakub Stachowski <qbast@go2.pl>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KDNSSDSERVICETYPEBROWSER_H
 #define KDNSSDSERVICETYPEBROWSER_H
 
-#include <QtCore/QObject>
-#include <dnssd/remoteservice.h>
+#include "remoteservice.h"
+#include <QObject>
+#include <QtContainerFwd>
+#include <memory>
 
-class QStringList;
 namespace KDNSSD
 {
 class ServiceTypeBrowserPrivate;
 
 /**
- * @class ServiceBrowser servicebrowser.h KDNSSD/ServiceBrowser
+ * @class ServiceTypeBrowser servicetypebrowser.h KDNSSD/ServiceTypeBrowser
  * @short Browses the service types being published on a domain
  *
  * This class is mostly useful for generic utilities for
- * browsing all the published services on a local network.
+ * browsing all the published service types on a local network.
  * Applications that wish to find out about available services
  * of a particular type (such as web servers) should use
  * ServiceBrowser.
@@ -63,10 +52,9 @@ public:
      *
      * @see startBrowse() and ServiceBrowser::isAvailable()
      */
-    explicit ServiceTypeBrowser(const QString &domain = QString(),
-                                QObject *parent = nullptr);
+    explicit ServiceTypeBrowser(const QString &domain = QString(), QObject *parent = nullptr);
 
-    ~ServiceTypeBrowser();
+    ~ServiceTypeBrowser() override;
 
     /**
      * All the service types currently being published
@@ -80,7 +68,7 @@ public:
      *
      * Only the first call to this function will have any effect.
      *
-     * Browsing stops when the ServiceBrowser object is destroyed.
+     * Browsing stops when the ServiceTypeBrowser object is destroyed.
      *
      * @warning The serviceTypeAdded() signal may be emitted before this
      *          function returns.
@@ -89,18 +77,6 @@ public:
      */
     void startBrowse();
 
-#ifndef KDNSSD_NO_DEPRECATED
-    /**
-     * This method is unnecessary, since it is safe to call startBrowse()
-     * multiple times.
-     * @deprecated since 4.0, just call startBrowse() again.
-     */
-    KDNSSD_DEPRECATED bool isRunning() const
-    {
-        return false;
-    }
-#endif
-
 Q_SIGNALS:
     /**
      * Emitted when there are no more services of this type
@@ -150,7 +126,8 @@ Q_SIGNALS:
 
 private:
     friend class ServiceTypeBrowserPrivate;
-    ServiceTypeBrowserPrivate *const d;
+    std::unique_ptr<ServiceTypeBrowserPrivate> const d;
+    Q_DECLARE_PRIVATE_D(d, ServiceTypeBrowser)
 };
 
 }
